//
//  ReparirChildBillViewModel.swift
//  IFS
//
//  Created by 曹云霄 on 2018/1/8.
//  Copyright © 2018年 上海勾芒信息科技有限公司. All rights reserved.
//

import UIKit
import RxSwift
import RxCocoa

class ReparirChildBillViewModel: BaseViewModel {

    /// RxSwift自动释放
    let disposeBag = DisposeBag()
    
    /// 子工单保存或者提交Model
    lazy final var childBillSaveModel: ChildBillSaveOrUpdateModel = {
        var childBillSaveModel = ChildBillSaveOrUpdateModel()
        return childBillSaveModel
    }()
    
    /// 过滤ViewModel
    lazy final var filterViewModel: FilterViewModel = {
        var filterViewModel = FilterViewModel()
        return filterViewModel
    }()
}

extension ReparirChildBillViewModel {
    
    // MARK: - 保存子工单
    func saveChildBillAction() ->Observable<Void> {
        return Observable.create({ (observer) -> Disposable in
            Network.request(target: .SaveChildBill(self.childBillSaveModel), success: { (json) in
                let resultModel = PublicResultModel(fromJson: json)
                if resultModel.success {
                    observer.onNext(())
                }else {
                    ShowMessage(resultModel.message)
                }
            }, failure: { (error) in
                ShowMessage(error.localizedDescription)
            })
            return Disposables.create()
        })
    }
}

extension ReparirChildBillViewModel {
    
    /// 完成部门工单界面item对应事件
    func didSelectRowAtIndexPath(_ indexPath: IndexPath, _ controller: RepairOrderEditSonOrderViewController) {
        switch indexPath {
        case IndexPath(row: 0, section: 0):
            filterViewModel.queryToolOption().subscribe(onNext: {[weak self] (result) in
                YXPickerManager.share().showGeneralPickerView(kMainColor, dataArray: result, defaultString: controller.toolOptionLabel.text, commit: { (text, index) in
                    controller.toolOptionLabel.text = text
                    controller.toolOptionLabel.textColor = kBlackColor
                    self?.childBillSaveModel
                }, cancel: nil)
            }).disposed(by: disposeBag)
            break
        case IndexPath(row: 1, section: 0):
            filterViewModel.queryProtectOption().subscribe(onNext: {[weak self] (result) in
                YXPickerManager.share().showGeneralPickerView(kMainColor, dataArray: result, defaultString: controller.toolOptionLabel.text, commit: { (text, index) in
                    controller.toolOptionLabel.text = text
                    controller.toolOptionLabel.textColor = kBlackColor
                }, cancel: nil)
            }).disposed(by: disposeBag)
            break
        case IndexPath(row: 2, section: 0):
            filterViewModel.queryInitiator().subscribe(onNext: {[weak self] (result) in
                let publicFilterVc = FilterViewController.instantiateViewController(.Function) as! FilterViewController
                for model in result {
                    let filterModel = PublicFilterModel(uuid: model.uuid, title: model.name, isSelected: "\(kZERO)")
                    publicFilterVc.publicViewModel.filterArray.add(filterModel)
                }
                controller.pushVC(publicFilterVc)
                publicFilterVc.setNavigationTitle("选择出工人",.SINGLE, { (choices, index) in
                    let choiceModel = choices.first!
                    controller.workPersonLabel.text = choiceModel.title
                    controller.workPersonLabel.textColor = kBlackColor
                    let model = result[index!]
                    let user = UCN(model.login, model.name, model.uuid)
//                    self?.saveOrderModel.reportUser = user
                })
            }).disposed(by: disposeBag)
            break
        case IndexPath(row: 3, section: 0):
            let defaultDate = controller.placeTimeLabel.text == "请选择" ? NSDate().httpParameterString() : controller.placeTimeLabel.text
            YXPickerManager.share().showDatePickerView(kMainColor, datePickerModel: UIDatePickerMode.dateAndTime, minimumDate: Date(), maximumDate: nil, defaultDate: defaultDate, commit: {[weak self] (time) in
                controller.placeTimeLabel.text = time
                controller.placeTimeLabel.textColor = kBlackColor
//                self?.saveOrderModel.receiveTime = time
                }, cancel: nil)
            break
        case IndexPath(row: 4, section: 0):
            let defaultDate = controller.leaveTimeLabel.text == "请选择" ? NSDate().httpParameterString() : controller.leaveTimeLabel.text
            YXPickerManager.share().showDatePickerView(kMainColor, datePickerModel: UIDatePickerMode.dateAndTime, minimumDate: Date(), maximumDate: nil, defaultDate: defaultDate, commit: {[weak self] (time) in
                controller.leaveTimeLabel.text = time
                controller.leaveTimeLabel.textColor = kBlackColor
                }, cancel: nil)
            break
        case IndexPath(row: 5, section: 0):
            filterViewModel.queryBrokenOption().subscribe(onNext: {[weak self] (result) in
                YXPickerManager.share().showGeneralPickerView(kMainColor, dataArray: result, defaultString: controller.failureCauseLabel.text, commit: { (text, index) in
                    controller.failureCauseLabel.text = text
                    controller.failureCauseLabel.textColor = kBlackColor
                }, cancel: nil)
            }).disposed(by: disposeBag)
            break
        case IndexPath(row: 6, section: 0):
            filterViewModel.queryProcessMethods().subscribe(onNext: {[weak self] (result) in
                YXPickerManager.share().showGeneralPickerView(kMainColor, dataArray: result, defaultString: controller.processModeLabel.text, commit: { (text, index) in
                    controller.processModeLabel.text = text
                    controller.processModeLabel.textColor = kBlackColor
                }, cancel: nil)
            }).disposed(by: disposeBag)
            break
        default:
            break
        }
    }
}
